[pypy-svn] r34001 - in pypy/dist/pypy: annotation annotation/test interpreter interpreter/pyparser jit/codegen jit/codegen/i386 jit/codegen/i386/test jit/codegen/llgraph jit/codegen/ppc jit/codegen/test jit/hintannotator/test jit/llabstractinterp/test jit/timeshifter/test jit/tl lang/automata lang/automata/test module/__builtin__ module/_pickle_support module/_stackless module/_weakref module/rsocket objspace/cclp objspace/cclp/constraint objspace/cpy objspace/flow objspace/std rlib rlib/test rpython rpython/lltypesystem rpython/lltypesystem/test rpython/memory rpython/memory/test rpython/ootypesystem rpython/ootypesystem/test rpython/test translator/backendopt/test translator/c translator/c/test translator/cli translator/cli/test translator/js translator/js/test translator/llvm translator/llvm/test translator/stackless translator/test

cfbolz at codespeak.net cfbolz at codespeak.net
Wed Nov 1 12:49:51 CET 2006


Author: cfbolz
Date: Wed Nov  1 12:49:34 2006
New Revision: 34001

Added:
   pypy/dist/pypy/rlib/objectmodel.py
      - copied unchanged from r33974, pypy/dist/pypy/rpython/objectmodel.py
   pypy/dist/pypy/rlib/test/test_objectmodel.py
      - copied, changed from r33974, pypy/dist/pypy/rpython/test/test_objectmodel.py
Removed:
   pypy/dist/pypy/rpython/objectmodel.py
   pypy/dist/pypy/rpython/test/test_objectmodel.py
Modified:
   pypy/dist/pypy/annotation/bookkeeper.py
   pypy/dist/pypy/annotation/builtin.py
   pypy/dist/pypy/annotation/test/test_annrpython.py
   pypy/dist/pypy/interpreter/error.py
   pypy/dist/pypy/interpreter/pyframe.py
   pypy/dist/pypy/interpreter/pyopcode.py
   pypy/dist/pypy/interpreter/pyparser/ebnflexer.py
   pypy/dist/pypy/interpreter/typedef.py
   pypy/dist/pypy/jit/codegen/i386/rgenop.py
   pypy/dist/pypy/jit/codegen/i386/test/test_genc_ts.py
   pypy/dist/pypy/jit/codegen/i386/test/test_operation.py
   pypy/dist/pypy/jit/codegen/i386/test/test_rgenop.py
   pypy/dist/pypy/jit/codegen/llgraph/rgenop.py
   pypy/dist/pypy/jit/codegen/model.py
   pypy/dist/pypy/jit/codegen/ppc/rgenop.py
   pypy/dist/pypy/jit/codegen/test/rgenop_tests.py
   pypy/dist/pypy/jit/hintannotator/test/test_annotator.py
   pypy/dist/pypy/jit/llabstractinterp/test/test_llabstractinterp.py
   pypy/dist/pypy/jit/llabstractinterp/test/test_vlist.py
   pypy/dist/pypy/jit/timeshifter/test/test_portal.py
   pypy/dist/pypy/jit/timeshifter/test/test_promotion.py
   pypy/dist/pypy/jit/timeshifter/test/test_timeshift.py
   pypy/dist/pypy/jit/tl/tl.py
   pypy/dist/pypy/jit/tl/tlc.py
   pypy/dist/pypy/jit/tl/tlr.py
   pypy/dist/pypy/lang/automata/dfa.py
   pypy/dist/pypy/lang/automata/test/test_dfa.py
   pypy/dist/pypy/module/__builtin__/special.py
   pypy/dist/pypy/module/_pickle_support/maker.py
   pypy/dist/pypy/module/_stackless/clonable.py
   pypy/dist/pypy/module/_stackless/interp_clonable.py
   pypy/dist/pypy/module/_stackless/interp_coroutine.py
   pypy/dist/pypy/module/_weakref/interp__weakref.py
   pypy/dist/pypy/module/rsocket/rsocket.py
   pypy/dist/pypy/objspace/cclp/constraint/constraint.py
   pypy/dist/pypy/objspace/cclp/misc.py
   pypy/dist/pypy/objspace/cclp/scheduler.py
   pypy/dist/pypy/objspace/cclp/space.py
   pypy/dist/pypy/objspace/cclp/thread.py
   pypy/dist/pypy/objspace/cclp/thunk.py
   pypy/dist/pypy/objspace/cclp/variable.py
   pypy/dist/pypy/objspace/cpy/objspace.py
   pypy/dist/pypy/objspace/cpy/typedef.py
   pypy/dist/pypy/objspace/flow/framestate.py
   pypy/dist/pypy/objspace/std/dictmultiobject.py
   pypy/dist/pypy/objspace/std/dictobject.py
   pypy/dist/pypy/objspace/std/dictstrobject.py
   pypy/dist/pypy/objspace/std/objspace.py
   pypy/dist/pypy/objspace/std/setobject.py
   pypy/dist/pypy/objspace/std/smallintobject.py
   pypy/dist/pypy/objspace/std/stringobject.py
   pypy/dist/pypy/rlib/rarithmetic.py
   pypy/dist/pypy/rpython/llinterp.py
   pypy/dist/pypy/rpython/lltypesystem/llmemory.py
   pypy/dist/pypy/rpython/lltypesystem/lltype.py
   pypy/dist/pypy/rpython/lltypesystem/opimpl.py
   pypy/dist/pypy/rpython/lltypesystem/rbuiltin.py
   pypy/dist/pypy/rpython/lltypesystem/rclass.py
   pypy/dist/pypy/rpython/lltypesystem/rdict.py
   pypy/dist/pypy/rpython/lltypesystem/rstr.py
   pypy/dist/pypy/rpython/lltypesystem/test/test_llmemory.py
   pypy/dist/pypy/rpython/lltypesystem/test/test_rtagged.py
   pypy/dist/pypy/rpython/memory/gc.py
   pypy/dist/pypy/rpython/memory/lladdress.py
   pypy/dist/pypy/rpython/memory/support.py
   pypy/dist/pypy/rpython/memory/test/test_gc.py
   pypy/dist/pypy/rpython/memory/test/test_support.py
   pypy/dist/pypy/rpython/memory/test/test_transformed_gc.py
   pypy/dist/pypy/rpython/normalizecalls.py
   pypy/dist/pypy/rpython/ootypesystem/ootype.py
   pypy/dist/pypy/rpython/ootypesystem/rbuiltin.py
   pypy/dist/pypy/rpython/ootypesystem/rdict.py
   pypy/dist/pypy/rpython/ootypesystem/test/test_oortype.py
   pypy/dist/pypy/rpython/raddress.py
   pypy/dist/pypy/rpython/rbuiltin.py
   pypy/dist/pypy/rpython/rcpy.py
   pypy/dist/pypy/rpython/rdict.py
   pypy/dist/pypy/rpython/rint.py
   pypy/dist/pypy/rpython/rlist.py
   pypy/dist/pypy/rpython/test/test_nongc.py
   pypy/dist/pypy/rpython/test/test_rbuiltin.py
   pypy/dist/pypy/rpython/test/test_rconstantdict.py
   pypy/dist/pypy/rpython/test/test_rpbc.py
   pypy/dist/pypy/translator/backendopt/test/test_canraise.py
   pypy/dist/pypy/translator/backendopt/test/test_constfold.py
   pypy/dist/pypy/translator/backendopt/test/test_escape.py
   pypy/dist/pypy/translator/backendopt/test/test_malloc.py
   pypy/dist/pypy/translator/c/gc.py
   pypy/dist/pypy/translator/c/primitive.py
   pypy/dist/pypy/translator/c/test/test_backendoptimized.py
   pypy/dist/pypy/translator/c/test/test_boehm.py
   pypy/dist/pypy/translator/c/test/test_genc.py
   pypy/dist/pypy/translator/c/test/test_lladdresses.py
   pypy/dist/pypy/translator/c/test/test_newgc.py
   pypy/dist/pypy/translator/c/test/test_rtagged.py
   pypy/dist/pypy/translator/c/test/test_symbolic.py
   pypy/dist/pypy/translator/c/test/test_typed.py
   pypy/dist/pypy/translator/cli/database.py
   pypy/dist/pypy/translator/cli/test/test_constant.py
   pypy/dist/pypy/translator/cli/test/test_objectmodel.py
   pypy/dist/pypy/translator/js/jts.py
   pypy/dist/pypy/translator/js/test/test_genllvm.py
   pypy/dist/pypy/translator/llvm/database.py
   pypy/dist/pypy/translator/llvm/test/test_lladdresses.py
   pypy/dist/pypy/translator/llvm/test/test_symbolic.py
   pypy/dist/pypy/translator/stackless/transform.py
   pypy/dist/pypy/translator/test/test_simplify.py
Log:
move objectmodel


Modified: pypy/dist/pypy/annotation/bookkeeper.py
==============================================================================
--- pypy/dist/pypy/annotation/bookkeeper.py	(original)
+++ pypy/dist/pypy/annotation/bookkeeper.py	Wed Nov  1 12:49:34 2006
@@ -19,7 +19,7 @@
 from pypy.interpreter.argument import Arguments, ArgErr
 from pypy.rlib.rarithmetic import r_int, r_uint, r_ulonglong, r_longlong
 from pypy.rlib.rarithmetic import base_int
-from pypy.rpython.objectmodel import r_dict, Symbolic
+from pypy.rlib.objectmodel import r_dict, Symbolic
 from pypy.tool.algo.unionfind import UnionFind
 from pypy.rpython.lltypesystem import lltype, llmemory
 from pypy.rpython.ootypesystem import ootype

Modified: pypy/dist/pypy/annotation/builtin.py
==============================================================================
--- pypy/dist/pypy/annotation/builtin.py	(original)
+++ pypy/dist/pypy/annotation/builtin.py	Wed Nov  1 12:49:34 2006
@@ -16,7 +16,7 @@
 from pypy.annotation import description
 from pypy.objspace.flow.model import Constant
 import pypy.rlib.rarithmetic
-import pypy.rpython.objectmodel
+import pypy.rlib.objectmodel
 import pypy.rlib.rstack
 
 # convenience only!
@@ -356,13 +356,13 @@
 ##BUILTIN_ANALYZERS[pypy.rlib.rarithmetic.ovfcheck] = rarith_ovfcheck
 ##BUILTIN_ANALYZERS[pypy.rlib.rarithmetic.ovfcheck_lshift] = rarith_ovfcheck_lshift
 BUILTIN_ANALYZERS[pypy.rlib.rarithmetic.intmask] = rarith_intmask
-BUILTIN_ANALYZERS[pypy.rpython.objectmodel.instantiate] = robjmodel_instantiate
-BUILTIN_ANALYZERS[pypy.rpython.objectmodel.we_are_translated] = (
+BUILTIN_ANALYZERS[pypy.rlib.objectmodel.instantiate] = robjmodel_instantiate
+BUILTIN_ANALYZERS[pypy.rlib.objectmodel.we_are_translated] = (
     robjmodel_we_are_translated)
-BUILTIN_ANALYZERS[pypy.rpython.objectmodel.r_dict] = robjmodel_r_dict
-BUILTIN_ANALYZERS[pypy.rpython.objectmodel.hlinvoke] = robjmodel_hlinvoke
-BUILTIN_ANALYZERS[pypy.rpython.objectmodel.keepalive_until_here] = robjmodel_keepalive_until_here
-BUILTIN_ANALYZERS[pypy.rpython.objectmodel.hint] = robjmodel_hint
+BUILTIN_ANALYZERS[pypy.rlib.objectmodel.r_dict] = robjmodel_r_dict
+BUILTIN_ANALYZERS[pypy.rlib.objectmodel.hlinvoke] = robjmodel_hlinvoke
+BUILTIN_ANALYZERS[pypy.rlib.objectmodel.keepalive_until_here] = robjmodel_keepalive_until_here
+BUILTIN_ANALYZERS[pypy.rlib.objectmodel.hint] = robjmodel_hint
 BUILTIN_ANALYZERS[pypy.rpython.lltypesystem.llmemory.cast_ptr_to_adr] = llmemory_cast_ptr_to_adr
 BUILTIN_ANALYZERS[pypy.rpython.lltypesystem.llmemory.cast_adr_to_ptr] = llmemory_cast_adr_to_ptr
 BUILTIN_ANALYZERS[pypy.rpython.lltypesystem.llmemory.cast_adr_to_int] = llmemory_cast_adr_to_int
@@ -549,7 +549,7 @@
 def robjmodel_free_non_gc_object(obj):
     pass
 
-BUILTIN_ANALYZERS[pypy.rpython.objectmodel.free_non_gc_object] = (
+BUILTIN_ANALYZERS[pypy.rlib.objectmodel.free_non_gc_object] = (
     robjmodel_free_non_gc_object)
 
 #_________________________________

Modified: pypy/dist/pypy/annotation/test/test_annrpython.py
==============================================================================
--- pypy/dist/pypy/annotation/test/test_annrpython.py	(original)
+++ pypy/dist/pypy/annotation/test/test_annrpython.py	Wed Nov  1 12:49:34 2006
@@ -11,7 +11,7 @@
 from pypy.annotation.dictdef import DictDef
 from pypy.objspace.flow.model import *
 from pypy.rlib.rarithmetic import r_uint, base_int, r_longlong, r_ulonglong
-from pypy.rpython import objectmodel
+from pypy.rlib import objectmodel
 from pypy.objspace.flow import FlowObjSpace
 
 from pypy.translator.test import snippet

Modified: pypy/dist/pypy/interpreter/error.py
==============================================================================
--- pypy/dist/pypy/interpreter/error.py	(original)
+++ pypy/dist/pypy/interpreter/error.py	Wed Nov  1 12:49:34 2006
@@ -1,5 +1,5 @@
 import os, sys
-from pypy.rpython.objectmodel import we_are_translated
+from pypy.rlib.objectmodel import we_are_translated
 
 AUTO_DEBUG = os.getenv('PYPY_DEBUG')
 RECORD_INTERPLEVEL_TRACEBACK = True

Modified: pypy/dist/pypy/interpreter/pyframe.py
==============================================================================
--- pypy/dist/pypy/interpreter/pyframe.py	(original)
+++ pypy/dist/pypy/interpreter/pyframe.py	Wed Nov  1 12:49:34 2006
@@ -7,7 +7,7 @@
 from pypy.interpreter import pytraceback
 from pypy.rlib.rarithmetic import r_uint, intmask
 import opcode
-from pypy.rpython.objectmodel import we_are_translated, instantiate
+from pypy.rlib.objectmodel import we_are_translated, instantiate
 from pypy.rlib import rstack # for resume points
 
 
@@ -633,7 +633,7 @@
 
     def emptystack(self, frame):
         # propagate the exception to the caller
-        from pypy.rpython.objectmodel import we_are_translated
+        from pypy.rlib.objectmodel import we_are_translated
         if we_are_translated():
             raise self.operr
         else:

Modified: pypy/dist/pypy/interpreter/pyopcode.py
==============================================================================
--- pypy/dist/pypy/interpreter/pyopcode.py	(original)
+++ pypy/dist/pypy/interpreter/pyopcode.py	Wed Nov  1 12:49:34 2006
@@ -13,7 +13,7 @@
 from pypy.interpreter.pycode import PyCode
 from pypy.interpreter.opcodeorder import opcodeorder
 from pypy.tool.sourcetools import func_with_new_name
-from pypy.rpython.objectmodel import we_are_translated
+from pypy.rlib.objectmodel import we_are_translated
 from pypy.rlib.rarithmetic import intmask
 from pypy.tool import stdlib_opcode as pythonopcode
 from pypy.rlib import rstack # for resume points

Modified: pypy/dist/pypy/interpreter/pyparser/ebnflexer.py
==============================================================================
--- pypy/dist/pypy/interpreter/pyparser/ebnflexer.py	(original)
+++ pypy/dist/pypy/interpreter/pyparser/ebnflexer.py	Wed Nov  1 12:49:34 2006
@@ -22,7 +22,7 @@
     EOF: end of file
     SYMDEF: a symbol definition e.g. "file_input:"
     STRING: a simple string "'xxx'"
-    SYMBOL: a rule symbol usually appeary right of a SYMDEF
+    SYMBOL: a rule symbol usually appearing right of a SYMDEF
     tokens: '[', ']', '(' ,')', '*', '+', '|'
     """
     def __init__(self, inpstring ):

Modified: pypy/dist/pypy/interpreter/typedef.py
==============================================================================
--- pypy/dist/pypy/interpreter/typedef.py	(original)
+++ pypy/dist/pypy/interpreter/typedef.py	Wed Nov  1 12:49:34 2006
@@ -8,7 +8,7 @@
 from pypy.interpreter.baseobjspace import Wrappable, W_Root, ObjSpace
 from pypy.interpreter.error import OperationError
 from pypy.tool.sourcetools import compile2, func_with_new_name
-from pypy.rpython.objectmodel import instantiate
+from pypy.rlib.objectmodel import instantiate
 from pypy.rlib.rarithmetic import intmask
 
 class TypeDef:

Modified: pypy/dist/pypy/jit/codegen/i386/rgenop.py
==============================================================================
--- pypy/dist/pypy/jit/codegen/i386/rgenop.py	(original)
+++ pypy/dist/pypy/jit/codegen/i386/rgenop.py	Wed Nov  1 12:49:34 2006
@@ -1,11 +1,11 @@
 import sys
-from pypy.rpython.objectmodel import specialize
+from pypy.rlib.objectmodel import specialize
 from pypy.rpython.lltypesystem import lltype, llmemory
 from pypy.jit.codegen.i386.ri386 import *
 from pypy.jit.codegen.i386.codebuf import InMemoryCodeBuilder, CodeBlockOverflow
 from pypy.jit.codegen.model import AbstractRGenOp, GenLabel, GenBuilder
 from pypy.jit.codegen.model import GenVar, GenConst, CodeGenSwitch
-from pypy.rpython import objectmodel
+from pypy.rlib import objectmodel
 from pypy.rpython.annlowlevel import llhelper
 
 WORD = 4

Modified: pypy/dist/pypy/jit/codegen/i386/test/test_genc_ts.py
==============================================================================
--- pypy/dist/pypy/jit/codegen/i386/test/test_genc_ts.py	(original)
+++ pypy/dist/pypy/jit/codegen/i386/test/test_genc_ts.py	Wed Nov  1 12:49:34 2006
@@ -1,7 +1,7 @@
 import os, sys
 from pypy.annotation import model as annmodel
 from pypy.annotation.listdef import s_list_of_strings
-from pypy.rpython.objectmodel import keepalive_until_here
+from pypy.rlib.objectmodel import keepalive_until_here
 from pypy.jit.timeshifter.test import test_timeshift
 from pypy.translator.c.genc import CStandaloneBuilder
 from pypy.rlib.unroll import unrolling_iterable

Modified: pypy/dist/pypy/jit/codegen/i386/test/test_operation.py
==============================================================================
--- pypy/dist/pypy/jit/codegen/i386/test/test_operation.py	(original)
+++ pypy/dist/pypy/jit/codegen/i386/test/test_operation.py	Wed Nov  1 12:49:34 2006
@@ -1,5 +1,5 @@
 import py
-from pypy.rpython.objectmodel import specialize
+from pypy.rlib.objectmodel import specialize
 from pypy.annotation import model as annmodel
 from pypy.rpython.lltypesystem import lltype
 from pypy.translator.translator import TranslationContext, graphof

Modified: pypy/dist/pypy/jit/codegen/i386/test/test_rgenop.py
==============================================================================
--- pypy/dist/pypy/jit/codegen/i386/test/test_rgenop.py	(original)
+++ pypy/dist/pypy/jit/codegen/i386/test/test_rgenop.py	Wed Nov  1 12:49:34 2006
@@ -1,6 +1,6 @@
 from pypy.rpython.lltypesystem import lltype
 from pypy.rpython.llinterp import LLInterpreter
-from pypy.rpython.objectmodel import keepalive_until_here
+from pypy.rlib.objectmodel import keepalive_until_here
 from pypy.rpython.annlowlevel import MixLevelAnnotatorPolicy
 from pypy.translator.c.test import test_boehm
 from pypy.jit.codegen.i386.rgenop import RI386GenOp

Modified: pypy/dist/pypy/jit/codegen/llgraph/rgenop.py
==============================================================================
--- pypy/dist/pypy/jit/codegen/llgraph/rgenop.py	(original)
+++ pypy/dist/pypy/jit/codegen/llgraph/rgenop.py	Wed Nov  1 12:49:34 2006
@@ -1,4 +1,4 @@
-from pypy.rpython.objectmodel import specialize
+from pypy.rlib.objectmodel import specialize
 from pypy.rpython.lltypesystem import lltype
 from pypy.jit.codegen.model import AbstractRGenOp, GenLabel, GenBuilder
 from pypy.jit.codegen.model import GenVar, GenConst, CodeGenSwitch

Modified: pypy/dist/pypy/jit/codegen/model.py
==============================================================================
--- pypy/dist/pypy/jit/codegen/model.py	(original)
+++ pypy/dist/pypy/jit/codegen/model.py	Wed Nov  1 12:49:34 2006
@@ -1,4 +1,4 @@
-from pypy.rpython.objectmodel import specialize
+from pypy.rlib.objectmodel import specialize
 
 
 class NotConstant(Exception):

Modified: pypy/dist/pypy/jit/codegen/ppc/rgenop.py
==============================================================================
--- pypy/dist/pypy/jit/codegen/ppc/rgenop.py	(original)
+++ pypy/dist/pypy/jit/codegen/ppc/rgenop.py	Wed Nov  1 12:49:34 2006
@@ -1,7 +1,7 @@
 from pypy.jit.codegen.model import AbstractRGenOp, GenLabel, GenBuilder
 from pypy.jit.codegen.model import GenVar, GenConst, CodeGenSwitch
 from pypy.rpython.lltypesystem import lltype, llmemory
-from pypy.rpython.objectmodel import specialize, we_are_translated
+from pypy.rlib.objectmodel import specialize, we_are_translated
 from pypy.jit.codegen.ppc.conftest import option
 
 class Register(object):

Modified: pypy/dist/pypy/jit/codegen/test/rgenop_tests.py
==============================================================================
--- pypy/dist/pypy/jit/codegen/test/rgenop_tests.py	(original)
+++ pypy/dist/pypy/jit/codegen/test/rgenop_tests.py	Wed Nov  1 12:49:34 2006
@@ -1,5 +1,5 @@
 from pypy.rpython.annlowlevel import MixLevelAnnotatorPolicy
-from pypy.rpython.objectmodel import keepalive_until_here
+from pypy.rlib.objectmodel import keepalive_until_here
 from pypy.rpython.lltypesystem import lltype
 from pypy.translator.c.test import test_boehm
 from ctypes import c_void_p, cast, CFUNCTYPE, c_int

Modified: pypy/dist/pypy/jit/hintannotator/test/test_annotator.py
==============================================================================
--- pypy/dist/pypy/jit/hintannotator/test/test_annotator.py	(original)
+++ pypy/dist/pypy/jit/hintannotator/test/test_annotator.py	Wed Nov  1 12:49:34 2006
@@ -4,7 +4,7 @@
 from pypy.jit.hintannotator.bookkeeper import HintBookkeeper
 from pypy.jit.hintannotator.model import *
 from pypy.rpython.lltypesystem import lltype
-from pypy.rpython.objectmodel import hint
+from pypy.rlib.objectmodel import hint
 from pypy.annotation import model as annmodel
 from pypy.objspace.flow import model as flowmodel
 from pypy.annotation.policy import AnnotatorPolicy
@@ -350,7 +350,7 @@
     assert hs1.contentdef.degenerated
 
 def test_degenerated_merge_cross_substructure():
-    from pypy.rpython import objectmodel
+    from pypy.rlib import objectmodel
     S = lltype.Struct('S', ('n', lltype.Signed))
     T = lltype.GcStruct('T', ('s', S), ('s1', S), ('n', lltype.Float))
 

Modified: pypy/dist/pypy/jit/llabstractinterp/test/test_llabstractinterp.py
==============================================================================
--- pypy/dist/pypy/jit/llabstractinterp/test/test_llabstractinterp.py	(original)
+++ pypy/dist/pypy/jit/llabstractinterp/test/test_llabstractinterp.py	Wed Nov  1 12:49:34 2006
@@ -7,7 +7,7 @@
 from pypy.annotation import model as annmodel
 from pypy.jit.llabstractinterp.llabstractinterp import LLAbstractInterp, Policy
 from pypy.objspace.flow import model as flowmodel
-from pypy.rpython import objectmodel
+from pypy.rlib import objectmodel
 
 # one day maybe
 py.test.skip("XXX need to be ported to the newer rgenop interface")
@@ -424,7 +424,7 @@
     assert insns == {'int_lt': 1, 'int_add': 1, 'int_mul': 1}
 
 def test_hint():
-    from pypy.rpython.objectmodel import hint
+    from pypy.rlib.objectmodel import hint
     A = lltype.GcArray(lltype.Char, hints={'immutable': True})
     def ll_interp(code):
         accum = 0
@@ -449,7 +449,7 @@
     assert insns == {'int_add': 4, 'int_lt': 1}
 
 def test_hint_across_call():
-    from pypy.rpython.objectmodel import hint
+    from pypy.rlib.objectmodel import hint
     A = lltype.GcArray(lltype.Char, hints={'immutable': True})
     def ll_length(a):
         return len(a)
@@ -478,7 +478,7 @@
     assert insns == {'int_add': 4, 'int_lt': 1}
 
 def test_conditional_origin():
-    from pypy.rpython.objectmodel import hint
+    from pypy.rlib.objectmodel import hint
     def ll_function(x, y, variable):
         result = 0
         i = 0

Modified: pypy/dist/pypy/jit/llabstractinterp/test/test_vlist.py
==============================================================================
--- pypy/dist/pypy/jit/llabstractinterp/test/test_vlist.py	(original)
+++ pypy/dist/pypy/jit/llabstractinterp/test/test_vlist.py	Wed Nov  1 12:49:34 2006
@@ -4,7 +4,7 @@
 from pypy.jit.llabstractinterp.test.test_llabstractinterp import summary
 from pypy.rpython.llinterp import LLInterpreter
 from pypy.rpython.lltypesystem.rstr import string_repr
-from pypy.rpython.objectmodel import hint
+from pypy.rlib.objectmodel import hint
 
 policy = Policy(inlining=True, const_propagate=True, concrete_args=False,
                 oopspec=True)

Modified: pypy/dist/pypy/jit/timeshifter/test/test_portal.py
==============================================================================
--- pypy/dist/pypy/jit/timeshifter/test/test_portal.py	(original)
+++ pypy/dist/pypy/jit/timeshifter/test/test_portal.py	Wed Nov  1 12:49:34 2006
@@ -5,9 +5,9 @@
 from pypy.jit.timeshifter.test.test_timeshift import P_NOVIRTUAL
 from pypy.rpython.llinterp import LLInterpreter
 from pypy.objspace.flow.model import checkgraph, summary
-from pypy.rpython.objectmodel import hint
+from pypy.rlib.objectmodel import hint
 
-from pypy.rpython.objectmodel import hint
+from pypy.rlib.objectmodel import hint
 
 import py.test
 

Modified: pypy/dist/pypy/jit/timeshifter/test/test_promotion.py
==============================================================================
--- pypy/dist/pypy/jit/timeshifter/test/test_promotion.py	(original)
+++ pypy/dist/pypy/jit/timeshifter/test/test_promotion.py	Wed Nov  1 12:49:34 2006
@@ -2,7 +2,7 @@
 from pypy.rpython.lltypesystem import lltype
 from pypy.jit.timeshifter.test.test_timeshift import TimeshiftingTests
 from pypy.jit.timeshifter.test.test_timeshift import P_NOVIRTUAL
-from pypy.rpython.objectmodel import hint
+from pypy.rlib.objectmodel import hint
 
 
 class TestPromotion(TimeshiftingTests):

Modified: pypy/dist/pypy/jit/timeshifter/test/test_timeshift.py
==============================================================================
--- pypy/dist/pypy/jit/timeshifter/test/test_timeshift.py	(original)
+++ pypy/dist/pypy/jit/timeshifter/test/test_timeshift.py	Wed Nov  1 12:49:34 2006
@@ -7,7 +7,7 @@
 from pypy.jit.timeshifter import rtimeshift, rvalue
 from pypy.objspace.flow.model import summary
 from pypy.rpython.lltypesystem import lltype, llmemory, rstr
-from pypy.rpython.objectmodel import hint, keepalive_until_here
+from pypy.rlib.objectmodel import hint, keepalive_until_here
 from pypy.rlib.unroll import unrolling_iterable
 from pypy.rpython.annlowlevel import PseudoHighLevelCallable
 from pypy.rpython.module.support import LLSupport

Modified: pypy/dist/pypy/jit/tl/tl.py
==============================================================================
--- pypy/dist/pypy/jit/tl/tl.py	(original)
+++ pypy/dist/pypy/jit/tl/tl.py	Wed Nov  1 12:49:34 2006
@@ -2,7 +2,7 @@
 
 import py
 from pypy.jit.tl.opcode import *
-from pypy.rpython.objectmodel import hint
+from pypy.rlib.objectmodel import hint
 
 def char2int(c):
     t = ord(c)

Modified: pypy/dist/pypy/jit/tl/tlc.py
==============================================================================
--- pypy/dist/pypy/jit/tl/tlc.py	(original)
+++ pypy/dist/pypy/jit/tl/tlc.py	Wed Nov  1 12:49:34 2006
@@ -3,7 +3,7 @@
 import py
 from pypy.jit.tl.opcode import *
 from pypy.jit.tl import opcode as tlopcode
-from pypy.rpython.objectmodel import hint
+from pypy.rlib.objectmodel import hint
 
 class Obj(object):
 

Modified: pypy/dist/pypy/jit/tl/tlr.py
==============================================================================
--- pypy/dist/pypy/jit/tl/tlr.py	(original)
+++ pypy/dist/pypy/jit/tl/tlr.py	Wed Nov  1 12:49:34 2006
@@ -1,4 +1,4 @@
-from pypy.rpython.objectmodel import hint
+from pypy.rlib.objectmodel import hint
 
 
 MOV_A_R    = 1

Modified: pypy/dist/pypy/lang/automata/dfa.py
==============================================================================
--- pypy/dist/pypy/lang/automata/dfa.py	(original)
+++ pypy/dist/pypy/lang/automata/dfa.py	Wed Nov  1 12:49:34 2006
@@ -1,6 +1,6 @@
 " a very stripped down versio of cfbolz's algorithm/automaton module "
 
-from pypy.rpython.objectmodel import hint
+from pypy.rlib.objectmodel import hint
 from pypy.rpython.lltypesystem.lltype import GcArray, Signed, malloc
 
 class LexerError(Exception):

Modified: pypy/dist/pypy/lang/automata/test/test_dfa.py
==============================================================================
--- pypy/dist/pypy/lang/automata/test/test_dfa.py	(original)
+++ pypy/dist/pypy/lang/automata/test/test_dfa.py	Wed Nov  1 12:49:34 2006
@@ -8,7 +8,7 @@
 from pypy.jit.timeshifter.test.test_timeshift import P_NOVIRTUAL
 from pypy.rpython.llinterp import LLInterpreter
 from pypy.objspace.flow.model import checkgraph
-from pypy.rpython.objectmodel import hint
+from pypy.rlib.objectmodel import hint
 
 from pypy.lang.automata.dfa import *
 

Modified: pypy/dist/pypy/module/__builtin__/special.py
==============================================================================
--- pypy/dist/pypy/module/__builtin__/special.py	(original)
+++ pypy/dist/pypy/module/__builtin__/special.py	Wed Nov  1 12:49:34 2006
@@ -26,7 +26,7 @@
 def _pdb(space):
     """Run an interp-level pdb.
     This is not available in translated versions of PyPy."""
-    from pypy.rpython.objectmodel import we_are_translated
+    from pypy.rlib.objectmodel import we_are_translated
     if we_are_translated():
         raise OperationError(space.w_NotImplementedError,
                              space.wrap("Cannot use interp-level pdb in translated pypy"))

Modified: pypy/dist/pypy/module/_pickle_support/maker.py
==============================================================================
--- pypy/dist/pypy/module/_pickle_support/maker.py	(original)
+++ pypy/dist/pypy/module/_pickle_support/maker.py	Wed Nov  1 12:49:34 2006
@@ -5,7 +5,7 @@
 from pypy.interpreter.pyframe import PyFrame
 from pypy.interpreter.pytraceback import PyTraceback
 from pypy.interpreter.generator import GeneratorIterator
-from pypy.rpython.objectmodel import instantiate
+from pypy.rlib.objectmodel import instantiate
 from pypy.interpreter.argument import Arguments
 from pypy.interpreter.baseobjspace import ObjSpace, W_Root
 from pypy.objspace.std.dicttype import dictiter_typedef

Modified: pypy/dist/pypy/module/_stackless/clonable.py
==============================================================================
--- pypy/dist/pypy/module/_stackless/clonable.py	(original)
+++ pypy/dist/pypy/module/_stackless/clonable.py	Wed Nov  1 12:49:34 2006
@@ -1,7 +1,7 @@
 from pypy.module._stackless.interp_coroutine import AbstractThunk, BaseCoState, Coroutine
 from pypy.module._stackless.interp_clonable import InterpClonableCoroutine
 
-from pypy.rpython.objectmodel import we_are_translated
+from pypy.rlib.objectmodel import we_are_translated
 from pypy.rlib.rgc import gc_swap_pool, gc_clone
 
 from pypy.module._stackless.stackless_flags import StacklessFlags

Modified: pypy/dist/pypy/module/_stackless/interp_clonable.py
==============================================================================
--- pypy/dist/pypy/module/_stackless/interp_clonable.py	(original)
+++ pypy/dist/pypy/module/_stackless/interp_clonable.py	Wed Nov  1 12:49:34 2006
@@ -1,6 +1,6 @@
 from pypy.module._stackless.interp_coroutine import AbstractThunk, BaseCoState, Coroutine
 from pypy.rlib.rgc import gc_swap_pool, gc_clone
-from pypy.rpython.objectmodel import we_are_translated
+from pypy.rlib.objectmodel import we_are_translated
 
 from pypy.interpreter.error import OperationError
 

Modified: pypy/dist/pypy/module/_stackless/interp_coroutine.py
==============================================================================
--- pypy/dist/pypy/module/_stackless/interp_coroutine.py	(original)
+++ pypy/dist/pypy/module/_stackless/interp_coroutine.py	Wed Nov  1 12:49:34 2006
@@ -31,7 +31,7 @@
 
 from pypy.interpreter.baseobjspace import Wrappable
 from pypy.rlib.rstack import yield_current_frame_to_caller, resume_point
-from pypy.rpython.objectmodel import we_are_translated
+from pypy.rlib.objectmodel import we_are_translated
 
 try:
     from py.magic import greenlet

Modified: pypy/dist/pypy/module/_weakref/interp__weakref.py
==============================================================================
--- pypy/dist/pypy/module/_weakref/interp__weakref.py	(original)
+++ pypy/dist/pypy/module/_weakref/interp__weakref.py	Wed Nov  1 12:49:34 2006
@@ -4,7 +4,7 @@
 from pypy.interpreter.error import OperationError
 from pypy.interpreter.typedef import GetSetProperty, TypeDef
 from pypy.interpreter.gateway import interp2app, ObjSpace
-from pypy.rpython.objectmodel import cast_weakgcaddress_to_object, cast_object_to_weakgcaddress
+from pypy.rlib.objectmodel import cast_weakgcaddress_to_object, cast_object_to_weakgcaddress
 from pypy.rpython.lltypesystem.llmemory import WEAKNULL
 
 

Modified: pypy/dist/pypy/module/rsocket/rsocket.py
==============================================================================
--- pypy/dist/pypy/module/rsocket/rsocket.py	(original)
+++ pypy/dist/pypy/module/rsocket/rsocket.py	Wed Nov  1 12:49:34 2006
@@ -11,7 +11,7 @@
 #   - methods makefile(),
 #   - SSL
 
-from pypy.rpython.objectmodel import instantiate
+from pypy.rlib.objectmodel import instantiate
 from pypy.module.rsocket import ctypes_socket as _c
 from ctypes import cast, POINTER, c_char, c_char_p, pointer, byref, c_void_p
 from ctypes import create_string_buffer, sizeof

Modified: pypy/dist/pypy/objspace/cclp/constraint/constraint.py
==============================================================================
--- pypy/dist/pypy/objspace/cclp/constraint/constraint.py	(original)
+++ pypy/dist/pypy/objspace/cclp/constraint/constraint.py	Wed Nov  1 12:49:34 2006
@@ -1,4 +1,4 @@
-from pypy.rpython.objectmodel import we_are_translated
+from pypy.rlib.objectmodel import we_are_translated
 from pypy.interpreter.error import OperationError
 from pypy.interpreter.baseobjspace import Wrappable
 from pypy.interpreter import baseobjspace, typedef, gateway

Modified: pypy/dist/pypy/objspace/cclp/misc.py
==============================================================================
--- pypy/dist/pypy/objspace/cclp/misc.py	(original)
+++ pypy/dist/pypy/objspace/cclp/misc.py	Wed Nov  1 12:49:34 2006
@@ -1,5 +1,5 @@
 from pypy.interpreter import gateway, baseobjspace
-from pypy.rpython.objectmodel import we_are_translated
+from pypy.rlib.objectmodel import we_are_translated
 
 # commonly imported there, used from types, variable, thread
 from pypy.module._stackless.clonable import ClonableCoroutine

Modified: pypy/dist/pypy/objspace/cclp/scheduler.py
==============================================================================
--- pypy/dist/pypy/objspace/cclp/scheduler.py	(original)
+++ pypy/dist/pypy/objspace/cclp/scheduler.py	Wed Nov  1 12:49:34 2006
@@ -1,4 +1,4 @@
-from pypy.rpython.objectmodel import we_are_translated
+from pypy.rlib.objectmodel import we_are_translated
 from pypy.interpreter.error import OperationError
 from pypy.interpreter import gateway, baseobjspace
 from pypy.objspace.std.listobject import W_ListObject

Modified: pypy/dist/pypy/objspace/cclp/space.py
==============================================================================
--- pypy/dist/pypy/objspace/cclp/space.py	(original)
+++ pypy/dist/pypy/objspace/cclp/space.py	Wed Nov  1 12:49:34 2006
@@ -1,4 +1,4 @@
-from pypy.rpython.objectmodel import we_are_translated
+from pypy.rlib.objectmodel import we_are_translated
 from pypy.interpreter import baseobjspace, gateway, argument, typedef
 from pypy.interpreter.function import Function
 from pypy.interpreter.pycode import PyCode

Modified: pypy/dist/pypy/objspace/cclp/thread.py
==============================================================================
--- pypy/dist/pypy/objspace/cclp/thread.py	(original)
+++ pypy/dist/pypy/objspace/cclp/thread.py	Wed Nov  1 12:49:34 2006
@@ -1,5 +1,5 @@
 from pypy.interpreter import gateway, baseobjspace, argument
-from pypy.rpython.objectmodel import we_are_translated
+from pypy.rlib.objectmodel import we_are_translated
 
 from pypy.objspace.cclp.types import W_Var, W_Future, W_FailedValue
 from pypy.objspace.cclp.misc import w, v, AppCoroutine, get_current_cspace

Modified: pypy/dist/pypy/objspace/cclp/thunk.py
==============================================================================
--- pypy/dist/pypy/objspace/cclp/thunk.py	(original)
+++ pypy/dist/pypy/objspace/cclp/thunk.py	Wed Nov  1 12:49:34 2006
@@ -10,7 +10,7 @@
 
 from pypy.objspace.std.listobject import W_ListObject
 from pypy.objspace.std.listobject import W_TupleObject
-from pypy.rpython.objectmodel import we_are_translated
+from pypy.rlib.objectmodel import we_are_translated
 
 def logic_args(args):
     "returns logic vars found in unpacked normalized args"

Modified: pypy/dist/pypy/objspace/cclp/variable.py
==============================================================================
--- pypy/dist/pypy/objspace/cclp/variable.py	(original)
+++ pypy/dist/pypy/objspace/cclp/variable.py	Wed Nov  1 12:49:34 2006
@@ -9,7 +9,7 @@
 from pypy.objspace.cclp.global_state import sched
 from pypy.objspace.cclp.types import deref, W_Var, W_CVar, W_Future, W_FailedValue
 
-from pypy.rpython.objectmodel import we_are_translated
+from pypy.rlib.objectmodel import we_are_translated
 
 W_Root = baseobjspace.W_Root
 all_mms = {}

Modified: pypy/dist/pypy/objspace/cpy/objspace.py
==============================================================================
--- pypy/dist/pypy/objspace/cpy/objspace.py	(original)
+++ pypy/dist/pypy/objspace/cpy/objspace.py	Wed Nov  1 12:49:34 2006
@@ -8,7 +8,7 @@
 from pypy.interpreter.function import Function
 from pypy.interpreter.typedef import GetSetProperty
 from pypy.rlib.rarithmetic import r_uint, r_longlong, r_ulonglong
-from pypy.rpython.objectmodel import we_are_translated, instantiate
+from pypy.rlib.objectmodel import we_are_translated, instantiate
 
 
 class CPyObjSpace(baseobjspace.ObjSpace):

Modified: pypy/dist/pypy/objspace/cpy/typedef.py
==============================================================================
--- pypy/dist/pypy/objspace/cpy/typedef.py	(original)
+++ pypy/dist/pypy/objspace/cpy/typedef.py	Wed Nov  1 12:49:34 2006
@@ -8,7 +8,7 @@
 from pypy.interpreter.baseobjspace import Wrappable, SpaceCache
 from pypy.interpreter.function import Function
 from pypy.interpreter.typedef import GetSetProperty
-from pypy.rpython.objectmodel import we_are_translated
+from pypy.rlib.objectmodel import we_are_translated
 from pypy.rpython.rcpy import CPyTypeInterface, cpy_export, cpy_import
 from pypy.rpython.rcpy import cpy_typeobject, rpython_object, cpy_allocate
 from pypy.rpython.rcpy import init_rpython_data, get_rpython_data

Modified: pypy/dist/pypy/objspace/flow/framestate.py
==============================================================================
--- pypy/dist/pypy/objspace/flow/framestate.py	(original)
+++ pypy/dist/pypy/objspace/flow/framestate.py	Wed Nov  1 12:49:34 2006
@@ -1,6 +1,6 @@
 from pypy.interpreter.pyframe import PyFrame, SuspendedUnroller
 from pypy.interpreter.error import OperationError
-from pypy.rpython.objectmodel import instantiate
+from pypy.rlib.objectmodel import instantiate
 from pypy.rlib.unroll import SpecTag
 from pypy.objspace.flow.model import *
 

Modified: pypy/dist/pypy/objspace/std/dictmultiobject.py
==============================================================================
--- pypy/dist/pypy/objspace/std/dictmultiobject.py	(original)
+++ pypy/dist/pypy/objspace/std/dictmultiobject.py	Wed Nov  1 12:49:34 2006
@@ -2,7 +2,7 @@
 from pypy.objspace.std.objspace import *
 from pypy.interpreter import gateway
 
-from pypy.rpython.objectmodel import r_dict, we_are_translated
+from pypy.rlib.objectmodel import r_dict, we_are_translated
 
 def _is_str(space, w_key):
     return space.is_w(space.type(w_key), space.w_str)

Modified: pypy/dist/pypy/objspace/std/dictobject.py
==============================================================================
--- pypy/dist/pypy/objspace/std/dictobject.py	(original)
+++ pypy/dist/pypy/objspace/std/dictobject.py	Wed Nov  1 12:49:34 2006
@@ -8,7 +8,7 @@
 from pypy.objspace.std.objspace import *
 from pypy.interpreter import gateway
 
-from pypy.rpython.objectmodel import r_dict
+from pypy.rlib.objectmodel import r_dict
 
 
 class W_DictObject(W_Object):

Modified: pypy/dist/pypy/objspace/std/dictstrobject.py
==============================================================================
--- pypy/dist/pypy/objspace/std/dictstrobject.py	(original)
+++ pypy/dist/pypy/objspace/std/dictstrobject.py	Wed Nov  1 12:49:34 2006
@@ -1,7 +1,7 @@
 from pypy.objspace.std.objspace import *
 from pypy.interpreter import gateway
 
-from pypy.rpython.objectmodel import r_dict
+from pypy.rlib.objectmodel import r_dict
 
 class W_DictStrObject(W_Object):
     from pypy.objspace.std.dicttype import dict_typedef as typedef

Modified: pypy/dist/pypy/objspace/std/objspace.py
==============================================================================
--- pypy/dist/pypy/objspace/std/objspace.py	(original)
+++ pypy/dist/pypy/objspace/std/objspace.py	Wed Nov  1 12:49:34 2006
@@ -2,7 +2,7 @@
 from pypy.interpreter.baseobjspace import ObjSpace, Wrappable
 from pypy.interpreter.error import OperationError, debug_print
 from pypy.interpreter.typedef import get_unique_interplevel_subclass
-from pypy.rpython.objectmodel import instantiate
+from pypy.rlib.objectmodel import instantiate
 from pypy.interpreter.gateway import PyPyCacheDir
 from pypy.tool.cache import Cache 
 from pypy.tool.sourcetools import func_with_new_name

Modified: pypy/dist/pypy/objspace/std/setobject.py
==============================================================================
--- pypy/dist/pypy/objspace/std/setobject.py	(original)
+++ pypy/dist/pypy/objspace/std/setobject.py	Wed Nov  1 12:49:34 2006
@@ -1,6 +1,6 @@
 from pypy.objspace.std.objspace import W_Object, OperationError
 from pypy.objspace.std.objspace import registerimplementation, register_all
-from pypy.rpython.objectmodel import r_dict
+from pypy.rlib.objectmodel import r_dict
 from pypy.rlib.rarithmetic import intmask, r_uint
 from pypy.interpreter import gateway
 

Modified: pypy/dist/pypy/objspace/std/smallintobject.py
==============================================================================
--- pypy/dist/pypy/objspace/std/smallintobject.py	(original)
+++ pypy/dist/pypy/objspace/std/smallintobject.py	Wed Nov  1 12:49:34 2006
@@ -7,7 +7,7 @@
 from pypy.rlib.rarithmetic import ovfcheck, ovfcheck_lshift, LONG_BIT, r_uint
 from pypy.objspace.std.inttype import wrapint
 from pypy.objspace.std.intobject import W_IntObject
-from pypy.rpython.objectmodel import UnboxedValue
+from pypy.rlib.objectmodel import UnboxedValue
 
 # XXX this is a complete copy of intobject.py.  Find a better but still
 # XXX annotator-friendly way to share code...

Modified: pypy/dist/pypy/objspace/std/stringobject.py
==============================================================================
--- pypy/dist/pypy/objspace/std/stringobject.py	(original)
+++ pypy/dist/pypy/objspace/std/stringobject.py	Wed Nov  1 12:49:34 2006
@@ -3,7 +3,7 @@
 from pypy.objspace.std.objspace import *
 from pypy.interpreter import gateway
 from pypy.rlib.rarithmetic import ovfcheck, _hash_string
-from pypy.rpython.objectmodel import we_are_translated
+from pypy.rlib.objectmodel import we_are_translated
 from pypy.objspace.std.inttype import wrapint
 from pypy.objspace.std.sliceobject import W_SliceObject
 from pypy.objspace.std import slicetype

Modified: pypy/dist/pypy/rlib/rarithmetic.py
==============================================================================
--- pypy/dist/pypy/rlib/rarithmetic.py	(original)
+++ pypy/dist/pypy/rlib/rarithmetic.py	Wed Nov  1 12:49:34 2006
@@ -29,8 +29,9 @@
 
 """
 import math
-from pypy.rpython import extregistry, objectmodel
+from pypy.rpython import extregistry
 
+from pypy.rlib import objectmodel
 # set up of machine internals
 _bits = 0
 _itest = 1

Modified: pypy/dist/pypy/rpython/llinterp.py
==============================================================================
--- pypy/dist/pypy/rpython/llinterp.py	(original)
+++ pypy/dist/pypy/rpython/llinterp.py	Wed Nov  1 12:49:34 2006
@@ -3,7 +3,7 @@
 from pypy.rpython.lltypesystem import lltype, llmemory, lloperation, llheap
 from pypy.rpython.lltypesystem import rclass
 from pypy.rpython.ootypesystem import ootype
-from pypy.rpython.objectmodel import ComputedIntSymbolic
+from pypy.rlib.objectmodel import ComputedIntSymbolic
 
 import sys, os
 import math

Modified: pypy/dist/pypy/rpython/lltypesystem/llmemory.py
==============================================================================
--- pypy/dist/pypy/rpython/lltypesystem/llmemory.py	(original)
+++ pypy/dist/pypy/rpython/lltypesystem/llmemory.py	Wed Nov  1 12:49:34 2006
@@ -4,7 +4,7 @@
 
 # sizeof, offsetof
 
-from pypy.rpython.objectmodel import Symbolic
+from pypy.rlib.objectmodel import Symbolic
 from pypy.rpython.lltypesystem import lltype
 
 class AddressOffset(Symbolic):

Modified: pypy/dist/pypy/rpython/lltypesystem/lltype.py
==============================================================================
--- pypy/dist/pypy/rpython/lltypesystem/lltype.py	(original)
+++ pypy/dist/pypy/rpython/lltypesystem/lltype.py	Wed Nov  1 12:49:34 2006
@@ -2,7 +2,7 @@
 from pypy.rlib.rarithmetic import r_int, r_uint, intmask
 from pypy.rlib.rarithmetic import r_ulonglong, r_longlong, base_int
 from pypy.rlib.rarithmetic import normalizedinttype
-from pypy.rpython.objectmodel import Symbolic
+from pypy.rlib.objectmodel import Symbolic
 from pypy.tool.uid import Hashable
 from pypy.tool.tls import tlsobject
 from pypy.tool.picklesupport import getstate_with_slots, setstate_with_slots, pickleable_weakref

Modified: pypy/dist/pypy/rpython/lltypesystem/opimpl.py
==============================================================================
--- pypy/dist/pypy/rpython/lltypesystem/opimpl.py	(original)
+++ pypy/dist/pypy/rpython/lltypesystem/opimpl.py	Wed Nov  1 12:49:34 2006
@@ -2,7 +2,7 @@
 from pypy.tool.sourcetools import func_with_new_name
 from pypy.rpython.lltypesystem import lltype, llmemory
 from pypy.rpython.lltypesystem.lloperation import opimpls
-from pypy.rpython.objectmodel import CDefinedIntSymbolic
+from pypy.rlib.objectmodel import CDefinedIntSymbolic
 
 # ____________________________________________________________
 # Implementation of the 'canfold' operations

Modified: pypy/dist/pypy/rpython/lltypesystem/rbuiltin.py
==============================================================================
--- pypy/dist/pypy/rpython/lltypesystem/rbuiltin.py	(original)
+++ pypy/dist/pypy/rpython/lltypesystem/rbuiltin.py	Wed Nov  1 12:49:34 2006
@@ -3,7 +3,7 @@
 from pypy.rpython.lltypesystem import lltype
 from pypy.rpython.lltypesystem import rclass
 from pypy.rpython.lltypesystem.rdict import rtype_r_dict
-from pypy.rpython import objectmodel
+from pypy.rlib import objectmodel
 from pypy.rpython.rmodel import TyperError, Constant
 from pypy.rpython.robject import pyobj_repr
 from pypy.rpython.rbool import bool_repr

Modified: pypy/dist/pypy/rpython/lltypesystem/rclass.py
==============================================================================
--- pypy/dist/pypy/rpython/lltypesystem/rclass.py	(original)
+++ pypy/dist/pypy/rpython/lltypesystem/rclass.py	Wed Nov  1 12:49:34 2006
@@ -19,7 +19,7 @@
 from pypy.rpython.robject import PyObjRepr, pyobj_repr
 from pypy.rpython.extregistry import ExtRegistryEntry
 from pypy.annotation import model as annmodel
-from pypy.rpython.objectmodel import UnboxedValue
+from pypy.rlib.objectmodel import UnboxedValue
 from pypy.rlib.rarithmetic import intmask
 
 #

Modified: pypy/dist/pypy/rpython/lltypesystem/rdict.py
==============================================================================
--- pypy/dist/pypy/rpython/lltypesystem/rdict.py	(original)
+++ pypy/dist/pypy/rpython/lltypesystem/rdict.py	Wed Nov  1 12:49:34 2006
@@ -5,9 +5,9 @@
      rtype_newdict, dum_variant, dum_keys, dum_values, dum_items
 from pypy.rpython.lltypesystem import lltype
 from pypy.rlib.rarithmetic import r_uint
-from pypy.rpython.objectmodel import hlinvoke
+from pypy.rlib.objectmodel import hlinvoke
 from pypy.rpython import robject
-from pypy.rpython import objectmodel
+from pypy.rlib import objectmodel
 from pypy.rpython import rmodel
 
 # ____________________________________________________________

Modified: pypy/dist/pypy/rpython/lltypesystem/rstr.py
==============================================================================
--- pypy/dist/pypy/rpython/lltypesystem/rstr.py	(original)
+++ pypy/dist/pypy/rpython/lltypesystem/rstr.py	Wed Nov  1 12:49:34 2006
@@ -1,7 +1,7 @@
 from weakref import WeakValueDictionary
 from pypy.annotation.pairtype import pairtype
 from pypy.rpython.error import TyperError
-from pypy.rpython.objectmodel import malloc_zero_filled, we_are_translated
+from pypy.rlib.objectmodel import malloc_zero_filled, we_are_translated
 from pypy.rpython.robject import PyObjRepr, pyobj_repr
 from pypy.rlib.rarithmetic import _hash_string
 from pypy.rpython.rmodel import inputconst, IntegerRepr

Modified: pypy/dist/pypy/rpython/lltypesystem/test/test_llmemory.py
==============================================================================
--- pypy/dist/pypy/rpython/lltypesystem/test/test_llmemory.py	(original)
+++ pypy/dist/pypy/rpython/lltypesystem/test/test_llmemory.py	Wed Nov  1 12:49:34 2006
@@ -525,8 +525,8 @@
 
 class TestWeakAddressLLinterp(object):
     def test_null(self):
-        from pypy.rpython.objectmodel import cast_weakgcaddress_to_object
-        from pypy.rpython.objectmodel import cast_object_to_weakgcaddress
+        from pypy.rlib.objectmodel import cast_weakgcaddress_to_object
+        from pypy.rlib.objectmodel import cast_object_to_weakgcaddress
         class A:
             pass
         def f():
@@ -534,8 +534,8 @@
         assert interpret(f, [])
     
     def test_attribute(object):
-        from pypy.rpython.objectmodel import cast_weakgcaddress_to_object
-        from pypy.rpython.objectmodel import cast_object_to_weakgcaddress
+        from pypy.rlib.objectmodel import cast_weakgcaddress_to_object
+        from pypy.rlib.objectmodel import cast_object_to_weakgcaddress
         class A:
             pass
         class B:

Modified: pypy/dist/pypy/rpython/lltypesystem/test/test_rtagged.py
==============================================================================
--- pypy/dist/pypy/rpython/lltypesystem/test/test_rtagged.py	(original)
+++ pypy/dist/pypy/rpython/lltypesystem/test/test_rtagged.py	Wed Nov  1 12:49:34 2006
@@ -1,7 +1,7 @@
 import sys
 from pypy.rpython.test.test_llinterp import interpret, get_interpreter
 from pypy.rpython.lltypesystem import lltype
-from pypy.rpython.objectmodel import UnboxedValue
+from pypy.rlib.objectmodel import UnboxedValue
 from pypy.translator.translator import graphof
 from pypy.objspace.flow.model import summary
 from pypy.translator.backendopt.all import backend_optimizations

Modified: pypy/dist/pypy/rpython/memory/gc.py
==============================================================================
--- pypy/dist/pypy/rpython/memory/gc.py	(original)
+++ pypy/dist/pypy/rpython/memory/gc.py	Wed Nov  1 12:49:34 2006
@@ -4,7 +4,7 @@
 from pypy.rpython.memory.gcheader import GCHeaderBuilder
 from pypy.rpython.memory import lltypesimulation
 from pypy.rpython.lltypesystem import lltype, llmemory
-from pypy.rpython.objectmodel import free_non_gc_object
+from pypy.rlib.objectmodel import free_non_gc_object
 from pypy.rpython.lltypesystem.lloperation import llop
 from pypy.rlib.rarithmetic import ovfcheck
 

Modified: pypy/dist/pypy/rpython/memory/lladdress.py
==============================================================================
--- pypy/dist/pypy/rpython/memory/lladdress.py	(original)
+++ pypy/dist/pypy/rpython/memory/lladdress.py	Wed Nov  1 12:49:34 2006
@@ -4,7 +4,7 @@
 from pypy.rpython.lltypesystem import llmemory
 from pypy.rpython.lltypesystem import lltype
 from pypy.rpython.memory.lltypelayout import convert_offset_to_int
-from pypy.rpython.objectmodel import ComputedIntSymbolic
+from pypy.rlib.objectmodel import ComputedIntSymbolic
 
 NULL = llmemory.NULL
 

Modified: pypy/dist/pypy/rpython/memory/support.py
==============================================================================
--- pypy/dist/pypy/rpython/memory/support.py	(original)
+++ pypy/dist/pypy/rpython/memory/support.py	Wed Nov  1 12:49:34 2006
@@ -1,6 +1,6 @@
 from pypy.rpython.lltypesystem import lltype, llmemory
 from pypy.rpython.memory.lltypelayout import sizeof
-from pypy.rpython.objectmodel import free_non_gc_object
+from pypy.rlib.objectmodel import free_non_gc_object
 
 INT_SIZE = sizeof(lltype.Signed)
 

Modified: pypy/dist/pypy/rpython/memory/test/test_gc.py
==============================================================================
--- pypy/dist/pypy/rpython/memory/test/test_gc.py	(original)
+++ pypy/dist/pypy/rpython/memory/test/test_gc.py	Wed Nov  1 12:49:34 2006
@@ -13,7 +13,7 @@
 from pypy.rpython.memory import gclltype
 from pypy.rpython.memory.test.test_llinterpsim import interpret
 from pypy.rpython.memory.lladdress import simulator
-from pypy.rpython.objectmodel import free_non_gc_object
+from pypy.rlib.objectmodel import free_non_gc_object
 
 def setup_module(mod):
     def stdout_ignore_ll_functions(msg):

Modified: pypy/dist/pypy/rpython/memory/test/test_support.py
==============================================================================
--- pypy/dist/pypy/rpython/memory/test/test_support.py	(original)
+++ pypy/dist/pypy/rpython/memory/test/test_support.py	Wed Nov  1 12:49:34 2006
@@ -1,4 +1,4 @@
-from pypy.rpython.objectmodel import free_non_gc_object
+from pypy.rlib.objectmodel import free_non_gc_object
 from pypy.rpython.memory.support import get_address_linked_list
 
 from pypy.rpython.test.test_llinterp import interpret

Modified: pypy/dist/pypy/rpython/memory/test/test_transformed_gc.py
==============================================================================
--- pypy/dist/pypy/rpython/memory/test/test_transformed_gc.py	(original)
+++ pypy/dist/pypy/rpython/memory/test/test_transformed_gc.py	Wed Nov  1 12:49:34 2006
@@ -12,7 +12,7 @@
 ## from pypy.rpython.memory import gclltype
 ## from pypy.rpython.memory.test.test_llinterpsim import interpret
 ## from pypy.rpython.memory.lladdress import simulator
-## from pypy.rpython.objectmodel import free_non_gc_object
+## from pypy.rlib.objectmodel import free_non_gc_object
 
 ## def setup_module(mod):
 ##     def stdout_ignore_ll_functions(msg):

Modified: pypy/dist/pypy/rpython/normalizecalls.py
==============================================================================
--- pypy/dist/pypy/rpython/normalizecalls.py	(original)
+++ pypy/dist/pypy/rpython/normalizecalls.py	Wed Nov  1 12:49:34 2006
@@ -9,7 +9,7 @@
 from pypy.tool.sourcetools import func_with_new_name
 from pypy.rpython.error import TyperError
 from pypy.rpython.rmodel import getgcflavor
-from pypy.rpython.objectmodel import instantiate, ComputedIntSymbolic
+from pypy.rlib.objectmodel import instantiate, ComputedIntSymbolic
 
 def normalize_call_familes(annotator):
     for callfamily in annotator.bookkeeper.pbc_maximal_call_families.infos():

Modified: pypy/dist/pypy/rpython/ootypesystem/ootype.py
==============================================================================
--- pypy/dist/pypy/rpython/ootypesystem/ootype.py	(original)
+++ pypy/dist/pypy/rpython/ootypesystem/ootype.py	Wed Nov  1 12:49:34 2006
@@ -3,7 +3,7 @@
         Primitive, isCompatibleType, enforce, saferecursive, SignedLongLong, UnsignedLongLong
 from pypy.rpython.lltypesystem.lltype import frozendict, isCompatibleType
 from pypy.rlib.rarithmetic import intmask
-from pypy.rpython import objectmodel
+from pypy.rlib import objectmodel
 from pypy.tool.uid import uid
 
 try:

Modified: pypy/dist/pypy/rpython/ootypesystem/rbuiltin.py
==============================================================================
--- pypy/dist/pypy/rpython/ootypesystem/rbuiltin.py	(original)
+++ pypy/dist/pypy/rpython/ootypesystem/rbuiltin.py	Wed Nov  1 12:49:34 2006
@@ -3,7 +3,7 @@
 from pypy.rpython.ootypesystem import rclass
 from pypy.rpython.ootypesystem.rdict import rtype_r_dict
 from pypy.objspace.flow.model import Constant
-from pypy.rpython import objectmodel
+from pypy.rlib import objectmodel
 from pypy.rpython.error import TyperError
 
 def rtype_new(hop):

Modified: pypy/dist/pypy/rpython/ootypesystem/rdict.py
==============================================================================
--- pypy/dist/pypy/rpython/ootypesystem/rdict.py	(original)
+++ pypy/dist/pypy/rpython/ootypesystem/rdict.py	Wed Nov  1 12:49:34 2006
@@ -9,9 +9,9 @@
 from pypy.rpython.ootypesystem import ootype
 from pypy.rpython.ootypesystem.rlist import ll_newlist
 from pypy.rlib.rarithmetic import r_uint
-from pypy.rpython.objectmodel import hlinvoke
+from pypy.rlib.objectmodel import hlinvoke
 from pypy.rpython import robject
-from pypy.rpython import objectmodel
+from pypy.rlib import objectmodel
 from pypy.rpython import rmodel
 from pypy.rpython import llinterp
 

Modified: pypy/dist/pypy/rpython/ootypesystem/test/test_oortype.py
==============================================================================
--- pypy/dist/pypy/rpython/ootypesystem/test/test_oortype.py	(original)
+++ pypy/dist/pypy/rpython/ootypesystem/test/test_oortype.py	Wed Nov  1 12:49:34 2006
@@ -7,7 +7,7 @@
 from pypy.objspace.flow import FlowObjSpace
 from pypy.translator.translator import TranslationContext, graphof
 from pypy.rpython.test.test_llinterp import interpret
-from pypy.rpython.objectmodel import r_dict
+from pypy.rlib.objectmodel import r_dict
 from pypy.rpython.ootypesystem import ooregistry # side effects
 
 def gengraph(f, args=[], viewBefore=False, viewAfter=False):

Modified: pypy/dist/pypy/rpython/raddress.py
==============================================================================
--- pypy/dist/pypy/rpython/raddress.py	(original)
+++ pypy/dist/pypy/rpython/raddress.py	Wed Nov  1 12:49:34 2006
@@ -145,7 +145,7 @@
 
     def convert_const(self, value):
         from pypy.rpython.lltypesystem import llmemory
-        from pypy.rpython.objectmodel import cast_object_to_weakgcaddress
+        from pypy.rlib.objectmodel import cast_object_to_weakgcaddress
         from pypy.objspace.flow.model import Constant
         assert isinstance(value, llmemory.fakeweakaddress)
         if value.ref is None:

Modified: pypy/dist/pypy/rpython/rbuiltin.py
==============================================================================
--- pypy/dist/pypy/rpython/rbuiltin.py	(original)
+++ pypy/dist/pypy/rpython/rbuiltin.py	Wed Nov  1 12:49:34 2006
@@ -2,8 +2,8 @@
 from pypy.annotation import model as annmodel
 from pypy.objspace.flow.model import Constant
 from pypy.rpython.lltypesystem import lltype, rclass, llmemory
-from pypy.rpython import objectmodel, rint, raddress
-from pypy.rlib import rarithmetic, rstack
+from pypy.rpython import rint, raddress
+from pypy.rlib import rarithmetic, rstack, objectmodel
 from pypy.rpython.error import TyperError
 from pypy.rpython.rmodel import Repr, IntegerRepr, inputconst
 from pypy.rpython.rrange import rtype_builtin_range, rtype_builtin_xrange

Modified: pypy/dist/pypy/rpython/rcpy.py
==============================================================================
--- pypy/dist/pypy/rpython/rcpy.py	(original)
+++ pypy/dist/pypy/rpython/rcpy.py	Wed Nov  1 12:49:34 2006
@@ -1,7 +1,7 @@
 from pypy.rpython.extregistry import ExtRegistryEntry
 from pypy.rpython.lltypesystem import lltype, llmemory
 from pypy.rpython.lltypesystem.lloperation import llop
-from pypy.rpython.objectmodel import CDefinedIntSymbolic
+from pypy.rlib.objectmodel import CDefinedIntSymbolic
 from pypy.objspace.flow.model import Constant, Variable
 from pypy.objspace.flow.model import FunctionGraph, Block, Link
 

Modified: pypy/dist/pypy/rpython/rdict.py
==============================================================================
--- pypy/dist/pypy/rpython/rdict.py	(original)
+++ pypy/dist/pypy/rpython/rdict.py	Wed Nov  1 12:49:34 2006
@@ -3,9 +3,9 @@
 from pypy.objspace.flow.model import Constant
 from pypy.rpython.lltypesystem import lltype
 from pypy.rlib.rarithmetic import r_uint
-from pypy.rpython.objectmodel import hlinvoke
+from pypy.rlib.objectmodel import hlinvoke
 from pypy.rpython import robject
-from pypy.rpython import objectmodel
+from pypy.rlib import objectmodel
 from pypy.rpython import rmodel
 
 def dum_keys(): pass

Modified: pypy/dist/pypy/rpython/rint.py
==============================================================================
--- pypy/dist/pypy/rpython/rint.py	(original)
+++ pypy/dist/pypy/rpython/rint.py	Wed Nov  1 12:49:34 2006
@@ -10,7 +10,7 @@
 from pypy.rlib.rarithmetic import intmask, r_int, r_uint, r_ulonglong, r_longlong
 from pypy.rpython.error import TyperError
 from pypy.rpython.rmodel import log
-from pypy.rpython import objectmodel
+from pypy.rlib import objectmodel
 
 _integer_reprs = {}
 def getintegerrepr(lltype, prefix=None):

Modified: pypy/dist/pypy/rpython/rlist.py
==============================================================================
--- pypy/dist/pypy/rpython/rlist.py	(original)
+++ pypy/dist/pypy/rpython/rlist.py	Wed Nov  1 12:49:34 2006
@@ -7,7 +7,7 @@
 from pypy.rpython.lltypesystem.lltype import typeOf, Ptr, Void, Signed, Bool
 from pypy.rpython.lltypesystem.lltype import nullptr, Char, UniChar
 from pypy.rpython import robject
-from pypy.rpython.objectmodel import malloc_zero_filled
+from pypy.rlib.objectmodel import malloc_zero_filled
 from pypy.rpython.annlowlevel import ADTInterface
 
 ADTIFixedList = ADTInterface(None, {

Modified: pypy/dist/pypy/rpython/test/test_nongc.py
==============================================================================
--- pypy/dist/pypy/rpython/test/test_nongc.py	(original)
+++ pypy/dist/pypy/rpython/test/test_nongc.py	Wed Nov  1 12:49:34 2006
@@ -3,7 +3,7 @@
 from pypy.annotation import model as annmodel
 from pypy.annotation.annrpython import RPythonAnnotator
 from pypy.rpython.rtyper import RPythonTyper
-from pypy.rpython.objectmodel import free_non_gc_object
+from pypy.rlib.objectmodel import free_non_gc_object
 from pypy.rpython.test.test_llinterp import interpret
 
 def test_free_non_gc_object():

Modified: pypy/dist/pypy/rpython/test/test_rbuiltin.py
==============================================================================
--- pypy/dist/pypy/rpython/test/test_rbuiltin.py	(original)
+++ pypy/dist/pypy/rpython/test/test_rbuiltin.py	Wed Nov  1 12:49:34 2006
@@ -1,6 +1,6 @@
 from pypy.translator.translator import graphof
 from pypy.rpython.test import test_llinterp
-from pypy.rpython.objectmodel import instantiate, we_are_translated
+from pypy.rlib.objectmodel import instantiate, we_are_translated
 from pypy.rpython.lltypesystem import lltype
 from pypy.tool import udir
 from pypy.rlib.rarithmetic import r_uint, intmask

Modified: pypy/dist/pypy/rpython/test/test_rconstantdict.py
==============================================================================
--- pypy/dist/pypy/rpython/test/test_rconstantdict.py	(original)
+++ pypy/dist/pypy/rpython/test/test_rconstantdict.py	Wed Nov  1 12:49:34 2006
@@ -1,5 +1,5 @@
 import py
-from pypy.rpython.objectmodel import r_dict
+from pypy.rlib.objectmodel import r_dict
 from pypy.rpython.test.tool import BaseRtypingTest, LLRtypeMixin, OORtypeMixin
 
 class BaseTestRconstantdict(BaseRtypingTest):

Modified: pypy/dist/pypy/rpython/test/test_rpbc.py
==============================================================================
--- pypy/dist/pypy/rpython/test/test_rpbc.py	(original)
+++ pypy/dist/pypy/rpython/test/test_rpbc.py	Wed Nov  1 12:49:34 2006
@@ -1456,7 +1456,7 @@
     rt.specialize()
 
     def ll_h(R, f, x):
-        from pypy.rpython.objectmodel import hlinvoke
+        from pypy.rlib.objectmodel import hlinvoke
         return hlinvoke(R, f, x, 2)
 
     from pypy.rpython import annlowlevel
@@ -1500,7 +1500,7 @@
     rt.specialize()
 
     def ll_h(R, f, x):
-        from pypy.rpython.objectmodel import hlinvoke
+        from pypy.rlib.objectmodel import hlinvoke
         return hlinvoke(R, f, x, 2)
 
     from pypy.rpython import annlowlevel
@@ -1549,7 +1549,7 @@
     rt.specialize()
 
     def ll_h(R, f, a):
-        from pypy.rpython.objectmodel import hlinvoke
+        from pypy.rlib.objectmodel import hlinvoke
         return hlinvoke(R, f, a)
 
     from pypy.rpython import annlowlevel
@@ -1599,7 +1599,7 @@
     rt.specialize()
 
     def ll_h(R, f, a):
-        from pypy.rpython.objectmodel import hlinvoke
+        from pypy.rlib.objectmodel import hlinvoke
         return hlinvoke(R, f, a)
 
     from pypy.rpython import annlowlevel
@@ -1660,7 +1660,7 @@
     rt.specialize()
 
     def ll_h(R, f, a):
-        from pypy.rpython.objectmodel import hlinvoke
+        from pypy.rlib.objectmodel import hlinvoke
         return hlinvoke(R, f, a)
 
     from pypy.rpython import annlowlevel

Modified: pypy/dist/pypy/translator/backendopt/test/test_canraise.py
==============================================================================
--- pypy/dist/pypy/translator/backendopt/test/test_canraise.py	(original)
+++ pypy/dist/pypy/translator/backendopt/test/test_canraise.py	Wed Nov  1 12:49:34 2006
@@ -74,7 +74,7 @@
     assert result
 
 def test_instantiate():
-    from pypy.rpython.objectmodel import instantiate
+    from pypy.rlib.objectmodel import instantiate
     class A:
         pass 
     class B(A):

Modified: pypy/dist/pypy/translator/backendopt/test/test_constfold.py
==============================================================================
--- pypy/dist/pypy/translator/backendopt/test/test_constfold.py	(original)
+++ pypy/dist/pypy/translator/backendopt/test/test_constfold.py	Wed Nov  1 12:49:34 2006
@@ -2,7 +2,7 @@
 from pypy.translator.translator import TranslationContext, graphof
 from pypy.rpython.llinterp import LLInterpreter
 from pypy.rpython.lltypesystem import lltype
-from pypy.rpython import objectmodel
+from pypy.rlib import objectmodel
 from pypy.translator.backendopt.constfold import constant_fold_graph
 from pypy import conftest
 

Modified: pypy/dist/pypy/translator/backendopt/test/test_escape.py
==============================================================================
--- pypy/dist/pypy/translator/backendopt/test/test_escape.py	(original)
+++ pypy/dist/pypy/translator/backendopt/test/test_escape.py	Wed Nov  1 12:49:34 2006
@@ -2,7 +2,7 @@
 from pypy.translator.backendopt.escape import AbstractDataFlowInterpreter, malloc_to_stack
 from pypy.translator.backendopt.support import find_backedges, find_loop_blocks
 from pypy.rpython.llinterp import LLInterpreter
-from pypy.rpython.objectmodel import instantiate
+from pypy.rlib.objectmodel import instantiate
 
 def build_adi(function, types):
     t = TranslationContext()

Modified: pypy/dist/pypy/translator/backendopt/test/test_malloc.py
==============================================================================
--- pypy/dist/pypy/translator/backendopt/test/test_malloc.py	(original)
+++ pypy/dist/pypy/translator/backendopt/test/test_malloc.py	Wed Nov  1 12:49:34 2006
@@ -119,7 +119,7 @@
     check(fn6, [int], [1], 12, must_be_removed=False)
 
 def test_with_keepalive():
-    from pypy.rpython.objectmodel import keepalive_until_here
+    from pypy.rlib.objectmodel import keepalive_until_here
     def fn1(x, y):
         if x > 0:
             t = x+y, x-y

Modified: pypy/dist/pypy/translator/c/gc.py
==============================================================================
--- pypy/dist/pypy/translator/c/gc.py	(original)
+++ pypy/dist/pypy/translator/c/gc.py	Wed Nov  1 12:49:34 2006
@@ -62,7 +62,7 @@
 class RefcountingInfo:
     static_deallocator = None
 
-from pypy.rpython.objectmodel import CDefinedIntSymbolic
+from pypy.rlib.objectmodel import CDefinedIntSymbolic
 
 class RefcountingGcPolicy(BasicGcPolicy):
     transformerclass = refcounting.RefcountingGCTransformer

Modified: pypy/dist/pypy/translator/c/primitive.py
==============================================================================
--- pypy/dist/pypy/translator/c/primitive.py	(original)
+++ pypy/dist/pypy/translator/c/primitive.py	Wed Nov  1 12:49:34 2006
@@ -1,6 +1,6 @@
 import sys
-from pypy.rpython.objectmodel import Symbolic, ComputedIntSymbolic
-from pypy.rpython.objectmodel import CDefinedIntSymbolic
+from pypy.rlib.objectmodel import Symbolic, ComputedIntSymbolic
+from pypy.rlib.objectmodel import CDefinedIntSymbolic
 from pypy.rpython.lltypesystem.lltype import *
 from pypy.rpython.lltypesystem.llmemory import Address, fakeaddress, \
      AddressOffset, ItemOffset, ArrayItemsOffset, FieldOffset, \

Modified: pypy/dist/pypy/translator/c/test/test_backendoptimized.py
==============================================================================
--- pypy/dist/pypy/translator/c/test/test_backendoptimized.py	(original)
+++ pypy/dist/pypy/translator/c/test/test_backendoptimized.py	Wed Nov  1 12:49:34 2006
@@ -1,7 +1,7 @@
 import py
 from pypy.translator.c.test.test_typed import TestTypedTestCase as _TestTypedTestCase
 from pypy.translator.backendopt.all import backend_optimizations
-from pypy.rpython import objectmodel
+from pypy.rlib import objectmodel
 from pypy.rlib.rarithmetic import r_uint, r_longlong, r_ulonglong
 from pypy import conftest
 

Modified: pypy/dist/pypy/translator/c/test/test_boehm.py
==============================================================================
--- pypy/dist/pypy/translator/c/test/test_boehm.py	(original)
+++ pypy/dist/pypy/translator/c/test/test_boehm.py	Wed Nov  1 12:49:34 2006
@@ -99,7 +99,7 @@
     def test_weakgcaddress_is_weak(self):
         from pypy.rpython.lltypesystem.lloperation import llop
         from pypy.rpython.lltypesystem import lltype
-        from pypy.rpython.objectmodel import cast_object_to_weakgcaddress
+        from pypy.rlib.objectmodel import cast_object_to_weakgcaddress
         class State:
             pass
         s = State()

Modified: pypy/dist/pypy/translator/c/test/test_genc.py
==============================================================================
--- pypy/dist/pypy/translator/c/test/test_genc.py	(original)
+++ pypy/dist/pypy/translator/c/test/test_genc.py	Wed Nov  1 12:49:34 2006
@@ -275,7 +275,7 @@
 
 
 def test_keepalive():
-    from pypy.rpython import objectmodel
+    from pypy.rlib import objectmodel
     def f():
         x = [1]
         y = ['b']

Modified: pypy/dist/pypy/translator/c/test/test_lladdresses.py
==============================================================================
--- pypy/dist/pypy/translator/c/test/test_lladdresses.py	(original)
+++ pypy/dist/pypy/translator/c/test/test_lladdresses.py	Wed Nov  1 12:49:34 2006
@@ -1,7 +1,7 @@
 from pypy.rpython.memory.lladdress import *
 from pypy.annotation.model import SomeAddress, SomeChar
 from pypy.translator.c.test.test_genc import compile
-from pypy.rpython.objectmodel import free_non_gc_object
+from pypy.rlib.objectmodel import free_non_gc_object
 
 def test_null():
     def f():
@@ -122,8 +122,8 @@
     assert fn(1) == 2
 
 def test_weakaddress():
-    from pypy.rpython.objectmodel import cast_object_to_weakgcaddress
-    from pypy.rpython.objectmodel import cast_weakgcaddress_to_object
+    from pypy.rlib.objectmodel import cast_object_to_weakgcaddress
+    from pypy.rlib.objectmodel import cast_weakgcaddress_to_object
     from pypy.rpython.lltypesystem.lloperation import llop
     class A(object):
         pass
@@ -139,8 +139,8 @@
     assert fn(10)
 
 def test_constant_weakaddress():
-    from pypy.rpython.objectmodel import cast_object_to_weakgcaddress
-    from pypy.rpython.objectmodel import cast_weakgcaddress_to_object
+    from pypy.rlib.objectmodel import cast_object_to_weakgcaddress
+    from pypy.rlib.objectmodel import cast_weakgcaddress_to_object
     from pypy.rpython.lltypesystem.lloperation import llop
     class A(object):
         pass

Modified: pypy/dist/pypy/translator/c/test/test_newgc.py
==============================================================================
--- pypy/dist/pypy/translator/c/test/test_newgc.py	(original)
+++ pypy/dist/pypy/translator/c/test/test_newgc.py	Wed Nov  1 12:49:34 2006
@@ -8,7 +8,7 @@
 from pypy.translator.c import genc, gc
 from pypy.rpython.lltypesystem import lltype, llmemory
 from pypy.rpython.lltypesystem.lloperation import llop
-from pypy.rpython.objectmodel import cast_weakgcaddress_to_object, cast_object_to_weakgcaddress
+from pypy.rlib.objectmodel import cast_weakgcaddress_to_object, cast_object_to_weakgcaddress
 from pypy.config.config import Config
 from pypy.config.pypyoption import pypy_optiondescription
 from pypy import conftest

Modified: pypy/dist/pypy/translator/c/test/test_rtagged.py
==============================================================================
--- pypy/dist/pypy/translator/c/test/test_rtagged.py	(original)
+++ pypy/dist/pypy/translator/c/test/test_rtagged.py	Wed Nov  1 12:49:34 2006
@@ -1,5 +1,5 @@
 import sys, os
-from pypy.rpython.objectmodel import UnboxedValue
+from pypy.rlib.objectmodel import UnboxedValue
 
 
 class A(object):

Modified: pypy/dist/pypy/translator/c/test/test_symbolic.py
==============================================================================
--- pypy/dist/pypy/translator/c/test/test_symbolic.py	(original)
+++ pypy/dist/pypy/translator/c/test/test_symbolic.py	Wed Nov  1 12:49:34 2006
@@ -2,7 +2,7 @@
 from pypy import conftest
 from pypy.rpython.lltypesystem import llmemory, lltype
 from pypy.rpython.memory import lladdress
-from pypy.rpython.objectmodel import ComputedIntSymbolic
+from pypy.rlib.objectmodel import ComputedIntSymbolic
 
 def getcompiled(f, args):
     t = Translation(f)

Modified: pypy/dist/pypy/translator/c/test/test_typed.py
==============================================================================
--- pypy/dist/pypy/translator/c/test/test_typed.py	(original)
+++ pypy/dist/pypy/translator/c/test/test_typed.py	Wed Nov  1 12:49:34 2006
@@ -711,7 +711,7 @@
         assert fn(1) == 42
 
     def test_r_dict_exceptions(self):
-        from pypy.rpython.objectmodel import r_dict
+        from pypy.rlib.objectmodel import r_dict
         
         def raising_hash(obj):
             if obj.startswith("bla"):

Modified: pypy/dist/pypy/translator/cli/database.py
==============================================================================
--- pypy/dist/pypy/translator/cli/database.py	(original)
+++ pypy/dist/pypy/translator/cli/database.py	Wed Nov  1 12:49:34 2006
@@ -15,7 +15,7 @@
 from pypy.rpython.lltypesystem import llmemory
 from pypy.translator.cli.opcodes import opcodes
 from pypy.translator.cli import dotnet
-from pypy.rpython.objectmodel import CDefinedIntSymbolic
+from pypy.rlib.objectmodel import CDefinedIntSymbolic
 
 try:
     set

Modified: pypy/dist/pypy/translator/cli/test/test_constant.py
==============================================================================
--- pypy/dist/pypy/translator/cli/test/test_constant.py	(original)
+++ pypy/dist/pypy/translator/cli/test/test_constant.py	Wed Nov  1 12:49:34 2006
@@ -100,7 +100,7 @@
         assert self.interpret(fn2, [1]) == True
 
     def test_customdict_circular(self):
-        from pypy.rpython.objectmodel import r_dict
+        from pypy.rlib.objectmodel import r_dict
         def key_eq(a, b):
             return a.x[0] == b.x[0]
         def key_hash(a):

Modified: pypy/dist/pypy/translator/cli/test/test_objectmodel.py
==============================================================================
--- pypy/dist/pypy/translator/js/jts.py	(original)
+++ pypy/dist/pypy/translator/js/jts.py	Wed Nov  1 12:49:34 2006
@@ -9,7 +9,7 @@
 from pypy.rpython.lltypesystem.lltype import SignedLongLong, UnsignedLongLong, Primitive
 from pypy.rpython.lltypesystem.lltype import Char, UniChar
 from pypy.rpython.ootypesystem.ootype import String, _string, List, StaticMethod
-from pypy.rpython.objectmodel import Symbolic
+from pypy.rlib.objectmodel import Symbolic
 
 from pypy.translator.js.log import log
 

Modified: pypy/dist/pypy/translator/js/test/test_genllvm.py
==============================================================================
--- pypy/dist/pypy/translator/js/test/test_genllvm.py	(original)
+++ pypy/dist/pypy/translator/js/test/test_genllvm.py	Wed Nov  1 12:49:34 2006
@@ -436,7 +436,7 @@
     assert fn() == some_test()
 
 def test_symbolic():
-    from pypy.rpython.objectmodel import malloc_zero_filled
+    from pypy.rlib.objectmodel import malloc_zero_filled
     
     def symbolic1():
         if malloc_zero_filled:

Modified: pypy/dist/pypy/translator/llvm/database.py
==============================================================================
--- pypy/dist/pypy/translator/llvm/database.py	(original)
+++ pypy/dist/pypy/translator/llvm/database.py	Wed Nov  1 12:49:34 2006
@@ -14,8 +14,8 @@
 from pypy.rpython.lltypesystem import lltype, llmemory
 from pypy.objspace.flow.model import Constant, Variable
 from pypy.rpython.memory.lladdress import NULL
-from pypy.rpython.objectmodel import Symbolic, ComputedIntSymbolic
-from pypy.rpython.objectmodel import CDefinedIntSymbolic
+from pypy.rlib.objectmodel import Symbolic, ComputedIntSymbolic
+from pypy.rlib.objectmodel import CDefinedIntSymbolic
 
 log = log.database 
 

Modified: pypy/dist/pypy/translator/llvm/test/test_lladdresses.py
==============================================================================
--- pypy/dist/pypy/translator/llvm/test/test_lladdresses.py	(original)
+++ pypy/dist/pypy/translator/llvm/test/test_lladdresses.py	Wed Nov  1 12:49:34 2006
@@ -1,7 +1,7 @@
 import py
 from pypy.rpython.memory.lladdress import *
 from pypy.annotation.model import SomeAddress, SomeChar
-from pypy.rpython.objectmodel import free_non_gc_object
+from pypy.rlib.objectmodel import free_non_gc_object
 
 from pypy.translator.llvm.test.runtest import *
 
@@ -171,8 +171,8 @@
     assert f() == 579
     
 def test_weakaddress():
-    from pypy.rpython.objectmodel import cast_object_to_weakgcaddress
-    from pypy.rpython.objectmodel import cast_weakgcaddress_to_object
+    from pypy.rlib.objectmodel import cast_object_to_weakgcaddress
+    from pypy.rlib.objectmodel import cast_weakgcaddress_to_object
     from pypy.rpython.lltypesystem.lloperation import llop
     class A(object):
         pass

Modified: pypy/dist/pypy/translator/llvm/test/test_symbolic.py
==============================================================================
--- pypy/dist/pypy/translator/llvm/test/test_symbolic.py	(original)
+++ pypy/dist/pypy/translator/llvm/test/test_symbolic.py	Wed Nov  1 12:49:34 2006
@@ -3,7 +3,7 @@
 from pypy import conftest
 from pypy.rpython.lltypesystem import llmemory, lltype
 from pypy.rpython.memory import lladdress
-from pypy.rpython.objectmodel import ComputedIntSymbolic
+from pypy.rlib.objectmodel import ComputedIntSymbolic
 
 from pypy.translator.llvm.test.runtest import *
 

Modified: pypy/dist/pypy/translator/stackless/transform.py
==============================================================================
--- pypy/dist/pypy/translator/stackless/transform.py	(original)
+++ pypy/dist/pypy/translator/stackless/transform.py	Wed Nov  1 12:49:34 2006
@@ -13,7 +13,7 @@
 from pypy.rpython.rbuiltin import gen_cast
 from pypy.rpython.rtyper import LowLevelOpList
 from pypy.rpython.module import ll_stackless, ll_stack
-from pypy.rpython.objectmodel import ComputedIntSymbolic
+from pypy.rlib.objectmodel import ComputedIntSymbolic
 from pypy.translator.backendopt import graphanalyze
 
 from pypy.translator.stackless.frame import SAVED_REFERENCE, STORAGE_TYPES

Modified: pypy/dist/pypy/translator/test/test_simplify.py
==============================================================================
--- pypy/dist/pypy/translator/test/test_simplify.py	(original)
+++ pypy/dist/pypy/translator/test/test_simplify.py	Wed Nov  1 12:49:34 2006
@@ -76,7 +76,7 @@
 
 
 def test_remove_pointless_keepalive():
-    from pypy.rpython import objectmodel
+    from pypy.rlib import objectmodel
     class C:
         y = None
         z1 = None



More information about the Pypy-commit mailing list
--- pypy/dist/pypy/translator/cli/test/test_objectmodel.py	(original)
+++ pypy/dist/pypy/translator/cli/test/test_objectmodel.py	Wed Nov  1 12:49:34 2006
@@ -1,8 +1,8 @@
 import py
 from pypy.translator.cli.test.runtest import CliTest
-from pypy.rpython.test.test_objectmodel import BaseTestObjectModel
+from pypy.rlib.test.test_objectmodel import BaseTestObjectModel
 
-from pypy.rpython.objectmodel import cast_object_to_weakgcaddress,\
+from pypy.rlib.objectmodel import cast_object_to_weakgcaddress,\
      cast_weakgcaddress_to_object
 
 def skip_r_dict(self):
@@ -12,7 +12,7 @@
     test_rtype_r_dict_bm = skip_r_dict
 
     def test_rdict_of_void_copy(self):
-        from pypy.rpython.test.test_objectmodel import r_dict, strange_key_eq, strange_key_hash
+        from pypy.rlib.test.test_objectmodel import r_dict, strange_key_eq, strange_key_hash
         def fn():
             d = r_dict(strange_key_eq, strange_key_hash)
             d['hello'] = None
@@ -22,7 +22,7 @@
         assert self.interpret(fn, []) == 2
 
     # this test is copied from TestLLtype in
     # rpython/test_objectmodel.py. It is not in TestOOtype because at
     # the moment llinterpret can't handle cast_*weakadr*
     def test_cast_to_and_from_weakaddress(self):
         class A(object):
@@ -22,7 +22,7 @@
 
     # this test is copied from TestLLtype in
-    # rpython/test_objectmodel.py. It is not in TestOOtype because at
+    # rlib/test_objectmodel.py. It is not in TestOOtype because at
     # the moment llinterpret can't handle cast_*weakadr*
     def test_cast_to_and_from_weakaddress(self):

Modified: pypy/dist/pypy/translator/js/jts.py
==============================================================================